.. _updates:

Community Updates
=================


Tracking development
--------------------

The best way to track the development of Dyndnsc is through
`the GitHub repo <https://github.com/infothrill/python-dyndnsc>`_.


.. include:: ../../CHANGELOG.rst

